==> gradle-5.5.1-all.zip: gradle-5.5.1/src/base-services/org/gradle/internal/resources/ExclusiveAccessResourceLock.java <==
/*
 * Copyright 2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.resources;

import org.gradle.api.Action;

import java.util.concurrent.locks.ReentrantLock;

public class ExclusiveAccessResourceLock extends AbstractTrackedResourceLock {
    private ReentrantLock lock = new ReentrantLock();

    public ExclusiveAccessResourceLock(String displayName, ResourceLockCoordinationService coordinationService, Action<ResourceLock> lockAction, Action<ResourceLock> unlockAction) {
        super(displayName, coordinationService, lockAction, unlockAction);
    }

    @Override
    protected boolean acquireLock() {
        return lock.tryLock();
    }

    @Override
    protected void releaseLock() {
        lock.unlock();
    }

    @Override
    protected boolean doIsLockedByCurrentThread() {
        return lock.isHeldByCurrentThread();
    }

    @Override
    protected boolean doIsLocked() {
        return lock.isLocked();
    }
}

==> gradle-9.4.0-20251202002548+0000-all.zip: gradle-9.4.0-20251202002548+0000/src/base-services/org/gradle/internal/resources/ExclusiveAccessResourceLock.java <==
/*
 * Copyright 2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.resources;

public class ExclusiveAccessResourceLock extends AbstractTrackedResourceLock {
    private Thread owner;

    public ExclusiveAccessResourceLock(String displayName, ResourceLockCoordinationService coordinationService, ResourceLockContainer owner) {
        super(displayName, coordinationService, owner);
    }

    @Override
    protected boolean acquireLock() {
        Thread currentThread = Thread.currentThread();
        if (owner == currentThread) {
            return true;
        }
        if (owner == null && canAcquire()) {
            owner = currentThread;
            return true;
        }
        return false;
    }

    protected boolean canAcquire() {
        return true;
    }

    @Override
    protected void releaseLock() {
        owner = null;
    }

    @Override
    protected boolean doIsLockedByCurrentThread() {
        return owner == Thread.currentThread();
    }

    @Override
    protected boolean doIsLocked() {
        return owner != null;
    }
}
